@@ -17,7 +17,7 @@ import os
 import sys
 
 from zipfile import ZipFile
-from StringIO import StringIO
+from io import BytesIO
 from urllib2 import urlopen, HTTPError
 
 from LbEnv import fixProjectCase
@@ -114,7 +114,7 @@ def main():
         print('cannot find data for the requested combination')
         exit(1)
 
-    arch = ZipFile(StringIO(arch_data))
+    arch = ZipFile(BytesIO(arch_data))
 
     print('Extracting', 'specific' if ignore_missing_dirs else 'all',
           'refs...')
