@@ -233,7 +233,9 @@ class Script(BaseScript):
                 from networkx.algorithms.dag import ancestors, descendants
                 deps = slot.dependencyGraph()
                 # - we have to build the projects explicitly listed
-                needed = set(slot.metadata['ci_test']['requested_projects'])
+                #   (excluding data packages)
+                needed = (set(slot.metadata['ci_test']['requested_projects']) &
+                          set(deps))
                 # - plus all projects that use the listed ones
                 needed.update(
                     list(
